# GeographicCounts

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**outcome_count_by_zip** | [**list[ZipData]**](ZipData.md) |  | [optional] 
**outcome_count_by_state** | [**list[StateData]**](StateData.md) |  | [optional] 
**intervention_count_by_zip** | [**list[ZipData]**](ZipData.md) |  | [optional] 
**intervention_count_by_state** | [**list[StateData]**](StateData.md) |  | [optional] 
**cohort_count_by_zip** | [**list[ZipData]**](ZipData.md) |  | [optional] 
**cohort_count_by_state** | [**list[StateData]**](StateData.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

